@@ -7,7 +7,6 @@ sequences, and displays some properties of the transformer model.
 import math
 import time
 from copy import deepcopy
-
 from pathlib import Path
 from typing import Any, Dict, Generator, Iterable, List, Optional, Tuple, Type, Union
 
@@ -19,10 +18,7 @@ from biotransformers.utils.compute_utils import Mutation, get_list_probs, mutati
 from biotransformers.utils.constant import NATURAL_AAS_LIST
 from biotransformers.utils.logger import logger  # noqa
 from biotransformers.utils.tqdm_utils import ProgressBar
-from biotransformers.utils.utils import (
-    init_model_sequences,
-    load_fasta,
-)
+from biotransformers.utils.utils import init_model_sequences, load_fasta
 from biotransformers.wrappers.language_model import LanguageModel
 from pytorch_lightning import Trainer
 from pytorch_lightning.callbacks import ModelCheckpoint
@@ -727,6 +723,7 @@ class TransformersWrapper:
         _, embeddings = self._model_evaluation(
             inputs, batch_size=batch_size, silent=silent
         )
+        self.delete_ray_workers()
         embeddings = [emb.cpu().numpy() for emb in embeddings]
         # Remove class token and padding
         # Use tranpose to filter on the two last dimensions. Doing this, we don't have to manage
@@ -751,7 +748,7 @@ class TransformersWrapper:
             embeddings_dict["mean"] = np.stack(
                 [e.transpose().mean(1).transpose() for e in filtered_embeddings]
             )
-        self.delete_ray_workers()
+
         return embeddings_dict
 
     def compute_accuracy(
@@ -953,8 +950,7 @@ class TransformersWrapper:
         )
 
         if self._num_gpus == 0:
-            pass
-            # raise ValueError("You try to train a transformers without GPU.")
+            raise ValueError("You try to train a transformers without GPU.")
 
         logger = CSVLogger(logs_save_dir, name=logs_name_exp)
         checkpoint_callback = None
